@@ -5,18 +5,16 @@ import zipfile
 import pickle
 import tcga.refs
 import pathlib
+import json
 
 
 class _:
     file = pathlib.Path(__file__).parent / "static/parsed/aaindex.pkl.zip"
     with zipfile.ZipFile(file, mode='r') as zf:
-        with zf.open(str(file.with_suffix(".pkl").name), mode='r') as fd:
+        with zf.open("data", mode='r') as fd:
             data = pickle.load(fd)
-
-    with (file.parent / F"{file.name}_meta.txt").open('r') as fd:
-        meta = {
-            'source': fd.read(),
-        }
+        with zf.open("meta", mode='r') as fd:
+            meta = {'source': json.loads(fd.read().decode())}
 
 
 data: pandas.Series
@@ -34,7 +32,9 @@ tcga.refs.annotations[indices] = _.meta
 tcga.refs.annotations[matrices] = _.meta
 tcga.refs.annotations[potentials] = _.meta
 
-del _
-
 if __name__ == '__main__':
     print(data[indices.sample(1).index[0]].I)
+    print(data['DOSZ010101'].M)
+    print(_.meta)
+
+del _
